DerivedProperty

Enum DerivedProperty 

pub enum DerivedProperty {
    PValid,
    FreePVal,
    ContextJ,
    ContextO,
    Disallowed,
    IdDis,
    Unassigned,
}
Represents the derived property value assigned to an Unicode code point. This value is parsed from the CSV maintained in the IANA registry.

Variants



PValid

Those code points that are allowed to be used in any PRECIS string class.



FreePVal

Those code points that are allowed to be used in the FreeformClass. In practice, the derived property ID_PVAL is not used in this specification, because every ID_PVAL code point is PVALID.



ContextJ

Contextual rule required for Join_controls Unicode code points.



ContextO

Contextual rule required for Others Unicode code points.



Disallowed

Those code points that are not permitted in any PRECIS string class.



IdDis

Those code points that are not allowed to be used in the IdentifierClass. In practice, the derived property FREE_DIS is not used in this specification, because every FREE_DIS code point is DISALLOWED.



Unassigned

Those code points that are not designated in the Unicode Standard.